@@ -38,6 +38,7 @@ from making_with_code_cli.cli_setup import (
     InstallAtom,
     InstallImageMagick,
     GHAuthentication,
+    GitConfiguration,
 )
 from making_with_code_cli.curriculum import (
     get_curriculum,
@@ -101,6 +102,7 @@ def setup(ctx, yes, teacher):
         InstallAtom(settings),
         InstallImageMagick(settings),
         GHAuthentication(settings),
+        GitConfiguration(settings),
     ]
     for task in tasks:
         task.run_task_if_needed()
@@ -130,6 +132,6 @@ def update():
                 else:
                     if 'init_action' in module:
                         rel_dir = module_dir.resolve().relative_to(mwc_home)
-                        msg = f"Initializing {module['slug']} at {rel_dir}. See {module['url']} for details."
-                        click.echo(confirm(msg))
+                        click.echo(confirm(f"Initializing {module['slug']} at {rel_dir}."))
+                        click.echo(confirm("See {module['url']} for details."))
                         G.init_module(module, module_dir)
